SELECT 1/pymysql - Criterion.rs

## SELECT 1/pymysql

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0056148 | 0.0058282 | 0.0056167
Mean | 16.420 ms | 16.638 ms | 16.855 ms
Std. Dev. | 986.26 µs | 1.1221 ms | 1.2406 ms
Median | 16.389 ms | 16.545 ms | 16.989 ms
MAD | 850.56 µs | 1.2181 ms | 1.6083 ms

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.